==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridSelectedCellsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedCellsChangedEventArgsDescription } from "./GridSelectedCellsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSelectedCellsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSelectedCellsChangedEventArgsDescriptionMetadata, _super);
    function GridSelectedCellsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSelectedCellsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSelectedCellsChangedEventArgsDescriptionMetadata.a == null) {
            GridSelectedCellsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSelectedCellsChangedEventArgsDescriptionMetadata.c(GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(GridSelectedCellsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedCellsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
        a.item("AddedCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
        a.item("RemovedCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
    };
    GridSelectedCellsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSelectedCellsChangedEventArgsDescriptionMetadata.b(a);
        a.u("GridSelectedCellsChangedEventArgs", function () { return new GridSelectedCellsChangedEventArgsDescription(); });
        a.t("GridSelectedCellsChangedEventArgs", GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedCellsChangedEventArgsDescriptionMetadata.$t = markType(GridSelectedCellsChangedEventArgsDescriptionMetadata, 'GridSelectedCellsChangedEventArgsDescriptionMetadata');
    GridSelectedCellsChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedCellsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSelectedCellsChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridSelectedCellsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedCellsChangedEventArgsDescription } from "./GridSelectedCellsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSelectedCellsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridSelectedCellsChangedEventArgsDescriptionMetadata, _super);
    function GridSelectedCellsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSelectedCellsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSelectedCellsChangedEventArgsDescriptionMetadata.a == null) {
            GridSelectedCellsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSelectedCellsChangedEventArgsDescriptionMetadata.c(GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridSelectedCellsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedCellsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
        a.item("AddedCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
        a.item("RemovedCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
    };
    GridSelectedCellsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSelectedCellsChangedEventArgsDescriptionMetadata.b(a);
        a.aa("GridSelectedCellsChangedEventArgs", function () { return new GridSelectedCellsChangedEventArgsDescription(); });
        a.z("GridSelectedCellsChangedEventArgs", GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedCellsChangedEventArgsDescriptionMetadata.$t = markType(GridSelectedCellsChangedEventArgsDescriptionMetadata, 'GridSelectedCellsChangedEventArgsDescriptionMetadata');
    GridSelectedCellsChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedCellsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSelectedCellsChangedEventArgsDescriptionMetadata };
